@@ -3,6 +3,8 @@ from upplib.common_package import *
 
 # 引入自定义的全部的包
 from upplib.index import *
+# 引入通用的工具包
+from upplib.util import *
 
 # 有关文件操作类的包
 from upplib.file import *
