@@ -263,15 +263,41 @@ def to_datetime(
         r_str: bool = False,
         error_is_none: bool = False,
         tz: Optional[Union[str, timezone]] = None,
-        default_tz: Union[str, timezone] = 'UTC+8'  # 默认时区改为 UTC+8
-) -> Union[datetime, str] | None:
+        default_tz: Union[str, timezone] = 'UTC+8'  # 默认时区为 UTC+8
+) -> Union[datetime, str, None]:
     """
     将字符串或时间戳转换为 datetime 对象，支持时区处理。
     error_is_none : 当发生错误的时候，是否返回 None
     """
+
+    def get_tz(tz_info: Union[str, timezone]) -> timezone:
+        """将时区信息转换为timezone对象"""
+        if isinstance(tz_info, timezone):
+            return tz_info
+        if not isinstance(tz_info, str):
+            raise ValueError(f"无效的时区格式: {tz_info}")
+
+        tz_str = tz_info.upper()
+        if tz_str == "UTC":
+            return timezone.utc
+
+        # 处理GMT格式，如GMT+08:00或GMT-5
+        gmt_match = re.match(r"GMT([+-]\d{1,2})(:\d{2})?$", tz_str)
+        if gmt_match:
+            hours = int(gmt_match.group(1))
+            return timezone(timedelta(hours=hours))
+
+        # 处理UTC格式，如UTC+8或UTC-05:00
+        utc_match = re.match(r"UTC([+-]\d{1,2})(:\d{2})?$", tz_str)
+        if utc_match:
+            hours = int(utc_match.group(1))
+            return timezone(timedelta(hours=hours))
+
+        raise ValueError(f"不支持的时区格式: {tz_info}")
+
     use_default_time = False
     if s is None or s == '':
-        dt = datetime.now(timezone.utc)
+        dt = datetime.now(get_tz(default_tz))
     else:
         s = str(s).strip()
         dt = None
@@ -282,64 +308,71 @@ def to_datetime(
         except ValueError:
             pass
 
-        # 2. 尝试解析时间戳（关键修改：先转 naive datetime，再附加时区）
+        # 2. 尝试解析带GMT时区的格式，如'2025/09/16 17:32:17.896 GMT+08:00'
+        if dt is None:
+            gmt_pattern = r"^(\d{4})[/-](\d{2})[/-](\d{2}) (\d{2}):(\d{2}):(\d{2})(\.\d+)? (GMT[+-]\d{1,2}(:\d{2})?)$"
+            match = re.match(gmt_pattern, s)
+            if match:
+                try:
+                    # 提取日期时间部分
+                    year, month, day = map(int, match.group(1, 2, 3))
+                    hour, minute, second = map(int, match.group(4, 5, 6))
+                    microsecond = 0
+                    if match.group(7):
+                        # 处理毫秒/微秒部分
+                        microsecond = int(float(match.group(7)) * 1e6)
+
+                    # 创建datetime对象
+                    dt = datetime(year, month, day, hour, minute, second, microsecond)
+
+                    # 应用时区
+                    tz_info = get_tz(match.group(8))
+                    dt = dt.replace(tzinfo=tz_info)
+                except ValueError:
+                    pass
+
+        # 3. 尝试解析时间戳
         if dt is None and re.match(r"^\d{1,19}$", s):
             timestamp = int(s)
             if len(s) > 10:  # 毫秒级时间戳
                 timestamp = timestamp // 1000
             # 先转为无时区的 datetime
             dt = datetime.fromtimestamp(timestamp)
-            # 然后附加默认时区
-            if isinstance(default_tz, str):
-                if default_tz.upper() == "UTC":
-                    default_tz = timezone.utc
-                else:
-                    offset = re.match(r"UTC([+-]\d{1,2})(:\d{2})?$", default_tz.upper())
-                    if offset:
-                        hours = int(offset.group(1))
-                        default_tz = timezone(timedelta(hours=hours))
-            dt = dt.replace(tzinfo=default_tz)
+            dt = dt.replace(tzinfo=get_tz(default_tz))
 
-        # 3. 其他解析逻辑保持不变...
+        # 4. 使用指定的pattern解析
         if dt is None and pattern is not None:
             try:
-                dt = datetime.strptime(s.split('.')[0], pattern)
+                # 移除可能的毫秒部分
+                s_without_ms = s.split('.')[0]
+                dt = datetime.strptime(s_without_ms, pattern)
             except ValueError:
                 pass
 
+        # 5. 尝试解析YYYY-MM-DD HH:MM:SS或YYYY/MM/DD HH:MM:SS格式
         if dt is None:
-            try:
-                dt = datetime.strptime(
-                    re.sub(r"[TZ]", " ", s).split('.')[0].strip(),
-                    "%Y-%m-%d %H:%M:%S"
-                )
-            except ValueError:
+            # 尝试处理不带时区的格式
+            formats = ["%Y-%m-%d %H:%M:%S", "%Y/%m/%d %H:%M:%S"]
+            for fmt in formats:
+                try:
+                    # 移除可能的毫秒和时区部分
+                    s_clean = re.sub(r"(\.\d+)|[TZ]|GMT.*$", " ", s).strip()
+                    dt = datetime.strptime(s_clean, fmt)
+                    break
+                except ValueError:
+                    continue
+
+            if dt is None:
                 use_default_time = True
                 dt = datetime.now()
 
         # 确保无时区时附加默认时区
         if dt.tzinfo is None:
-            if isinstance(default_tz, str):
-                if default_tz.upper() == "UTC":
-                    default_tz = timezone.utc
-                else:
-                    offset = re.match(r"UTC([+-]\d{1,2})(:\d{2})?$", default_tz.upper())
-                    if offset:
-                        hours = int(offset.group(1))
-                        default_tz = timezone(timedelta(hours=hours))
-            dt = dt.replace(tzinfo=default_tz)
+            dt = dt.replace(tzinfo=get_tz(default_tz))
 
     # 转换为目标时区
     if tz is not None:
-        if isinstance(tz, str):
-            if tz.upper() == "UTC":
-                tz = timezone.utc
-            else:
-                offset = re.match(r"UTC([+-]\d{1,2})(:\d{2})?$", tz.upper())
-                if offset:
-                    hours = int(offset.group(1))
-                    tz = timezone(timedelta(hours=hours))
-        dt = dt.astimezone(tz)
+        dt = dt.astimezone(get_tz(tz))
 
     if error_is_none and use_default_time:
         return None
@@ -348,8 +381,24 @@ def to_datetime(
 
 
 # 将字符串 s 转化成 datetime, 然后再次转化成 str
-def to_datetime_str(s: Any = None) -> datetime | str:
-    return to_datetime(s, r_str=True)
+def to_datetime_str(s: Any = None,
+                    pattern: str = None,
+                    pattern_str: str = None,
+                    tz: Optional[Union[str, timezone]] = None) -> datetime | str:
+    """
+    将 s 先转成 datetime, 然后再转成字符串
+
+    :param s: 输入值（可以是字符串或其他类型）
+    :param precision: 小数部分保留的位数（多余部分直接截断）
+    :return: 转换后的 float 值
+    """
+    r_s = to_datetime(s, pattern=pattern, tz=tz, r_str=False)
+    return r_s.isoformat() if pattern_str is None else r_s.strftime(pattern_str)
+
+
+def to_datetime_format(s: Any = None,
+                       pattern_str: str = "%Y-%m-%d %H:%M:%S") -> datetime | str:
+    return to_datetime_str(s, pattern=None, pattern_str=pattern_str, tz=None)
 
 
 # 时间加减
@@ -381,6 +430,28 @@ def get_timestamp(s: Any = None) -> int:
     return int(to_datetime(s).timestamp())
 
 
+def get_datetime_number_str(s: Any = None,
+                            length: int = None,
+                            remove_dz: bool = True,
+                            ) -> str:
+    """获取 datetime , 然后转成字符串, 然后, 只保留数字
+        Args:
+            s: 输入值，可以是任何类型，如果是None则使用当前时间
+            length: 可选参数，指定返回字符串的长度
+            remove_dz: 是否去掉时区
+        Returns:
+            str: 只包含数字的字符串
+        """
+    s1 = to_datetime(s)
+    digits_only = re.sub(r'\D', '', str(s1))
+    # 如果指定了长度，取最后length位
+    if length is not None and length > 0:
+        return digits_only[-length:] if len(digits_only) > length else digits_only
+    if len(digits_only) > 4 and remove_dz:
+        digits_only = digits_only[:-4]
+    return digits_only
+
+
 def get_timestamp_ms(s: Any = None) -> int:
     """获取 Unix 毫秒级时间戳"""
     return int(to_datetime(s).timestamp() * 1000)
@@ -754,13 +825,13 @@ def to_log_file(*args,
     )
     to_txt(data_param=[
         to_log(*args, time_prefix=time_prefix, line_with_space_count=line_with_space_count, interval=interval)],
-           file_name=('' if file_name_prefix is None else file_name_prefix)
-                     + (datetime.today().strftime('%Y-%m-%d') if file_name is None else file_name)
-                     + ('' if file_name_suffix is None else file_name_suffix),
-           file_path=str(file_path if file_path is not None else 'to_log_file'),
-           fixed_name=True,
-           mode=mode,
-           suffix='.log')
+        file_name=('' if file_name_prefix is None else file_name_prefix)
+                  + (datetime.today().strftime('%Y-%m-%d') if file_name is None else file_name)
+                  + ('' if file_name_suffix is None else file_name_suffix),
+        file_path=str(file_path if file_path is not None else 'to_log_file'),
+        fixed_name=True,
+        mode=mode,
+        suffix='.log')
 
 
 def to_log_txt(*args,
@@ -792,13 +863,13 @@ def to_log_txt(*args,
     )
     to_txt(data_param=[
         to_log(*args, time_prefix=time_prefix, line_with_space_count=line_with_space_count, interval=interval)],
-           file_name=('' if file_name_prefix is None else file_name_prefix)
-                     + (datetime.today().strftime('%Y-%m-%d') if file_name is None else file_name)
-                     + ('' if file_name_suffix is None else file_name_suffix),
-           file_path=str(file_path if file_path is not None else 'to_log_txt'),
-           mode=mode,
-           fixed_name=True,
-           suffix='.txt')
+        file_name=('' if file_name_prefix is None else file_name_prefix)
+                  + (datetime.today().strftime('%Y-%m-%d') if file_name is None else file_name)
+                  + ('' if file_name_suffix is None else file_name_suffix),
+        file_path=str(file_path if file_path is not None else 'to_log_txt'),
+        mode=mode,
+        fixed_name=True,
+        suffix='.txt')
 
 
 def check_file(file_name: str = None) -> None:
@@ -1586,31 +1657,3 @@ def to_csv(data_list: set | list | tuple | dict,
     with open(file_path + '/' + file_name, 'w', newline='') as f:
         writer = csv.writer(f)
         writer.writerows(d_list)
-
-
-def format_milliseconds(time_str):
-    # 匹配小数点后的数字（至少1位），并捕获时区部分
-    # param：2025-08-14T12:53:00.05382312323+07:00
-    # return：2025-08-14T12:53:00.0538+07:00
-    return re.sub(r'\.(\d+)([+-].*)?', lambda m: f".{m.group(1)[:4]}{m.group(2) or ''}", time_str)
-
-
-def get_log_msg(contents: dict) -> str:
-    """
-    获得日志
-    """
-    _time_ = None
-    if '_time_' in contents:
-        _time_ = format_milliseconds(contents['_time_'])
-    content = None
-    if 'content' in contents:
-        content = contents['content']
-    if content is None and 'message' in contents:
-        content = contents['message']
-    if content is not None and len(str(content).split(' ')) >= 2:
-        time_str = ' '.join(str(content).split(' ')[0:2])
-        time_1 = to_datetime(time_str, error_is_none=True)
-        if time_1 is not None:
-            content = content[len(time_str):]
-    _time_ = '' if _time_ is None else _time_
-    return _time_ + ' ' + content
